﻿Imports System.Linq
Imports System.ComponentModel
Imports System.Collections.Generic
Imports System.ComponentModel.DataAnnotations
Imports Infragistics.Web.Mvc

Public Class TestModel

    <Required(ErrorMessage:="Please supply a Name")>
    <Display(Name:="Test Name")>
    <StringLength(10, MinimumLength:=2, ErrorMessage:="Please supply a valid Name (between 2 and 10 characters long)")>
    Public Property Name As String

    <Display(Name:="Test Description")>
    <StringLength(100)>
    Public Property Description As String

    <Display(Name:="Persons List")>
    Public Property Persons As PersonList(Of Person)

    <Display(Name:="Persons List")>
    Public ReadOnly Property PersonsQueryable As IQueryable(Of Person)
        Get
            Return Persons.AsQueryable()
        End Get
    End Property

    Public Function PersonsGridModel() As GridModel

        Dim grdModel As GridModel = New GridModel()

        With grdModel

            .ID = "gridPersons"
            .PrimaryKey = "Key"
            .AutoCommit = True
            .AutoGenerateColumns = False
            .ShowHeader = True
            .Width = "100%"
            ' always add updating as first feature as it is referenced by index below!
            .Features.Add(New GridUpdating() With {.EditMode = GridEditMode.Cell, _
                                                   .EnableAddRow = True, _
                                                   .EnableDeleteRow = True, _
                                                   .Validation = True, _
                                                   .DeleteRowTooltip = "Delete Person", _
                                                   .AddRowTooltip = "Add Person"})
            .Features.Add(New GridPaging() With {.Type = OpType.Local, _
                                                 .PageSize = 5, _
                                                 .PrevPageLabelText = "Prev", _
                                                 .NextPageLabelText = "Next", _
                                                 .TotalRecordsCount = Persons.Count _
                                                })
            .Features.Add(New GridSorting() With {.Mode = SortingMode.Single})
            .Features.Add(New GridSelection() With {.Mode = SelectionMode.Cell, .MultipleSelection = False})
            .Columns.Add(New GridColumn() With {.Key = "FirstName", _
                                                .DataType = "String", _
                                                .Width = "50%"
                                                })
            .Columns.Add(New GridColumn() With {.Key = "LastName", _
                                                .DataType = "String", _
                                                .Width = "50%"
                                                })
            .Columns.Add(New GridColumn() With {.Key = "Key", _
                                                .Hidden = True, _
                                                .DataType = "String"
                                                })
            .DataSource = PersonsQueryable

        End With

        Dim oFeature As GridUpdating = grdModel.Features(0)
        Dim oSetting As ColumnUpdatingSetting = New ColumnUpdatingSetting() With {.ColumnKey = "FirstName", _
                                                                                  .EditorType = ColumnEditorType.Text, _
                                                                                  .Required = True, _
                                                                                  .Validation = True}

        oFeature.ColumnSettings.Add(oSetting)

        oSetting = New ColumnUpdatingSetting() With {.ColumnKey = "LastName", _
                                                     .EditorType = ColumnEditorType.Text, _
                                                     .Required = True, _
                                                     .Validation = True}

        Return grdModel

    End Function


End Class

Public Class PersonList(Of T As Person)
    Inherits BindingList(Of T)

End Class

Public Class Person
    Public Property Key As String
    Public Property FirstName As String
    Public Property LastName As String
End Class